#
# spec file for package mingw32-zlib
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw32-zlib
Version:        1.2.13
Release:        3.8
Summary:        Zlib compression library
License:        Zlib
Group:          Productivity/Archiving/Compression
URL:            https://www.zlib.net/
Source:         http://www.zlib.net/zlib-%{version}.tar.gz
Source1000:     %{name}-rpmlintrc
Patch0:         zlib-1.2.5-nostrip.patch
Patch1:         zlib-1.2.5-tml.patch
Patch2:         0001-cmake-Fix-pkgconfig-support-on-Windows.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  mingw32-cross-cmake
BuildRequires:  libtool
BuildRequires:  mingw32-cross-binutils
BuildRequires:  mingw32-cross-cmake
BuildRequires:  mingw32-cross-gcc
BuildRequires:  xz
%_mingw32_package_header_debug
BuildArch:      noarch

%description
zlib is a general-purpose lossless data-compression library,
implementing an API for the DEFLATE algorithm, the latter of
which is being used by, for example, gzip and the ZIP archive
format.

%package -n mingw32-zlib1
Summary:        Zlib compression library
Group:          System/Libraries
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description -n mingw32-zlib1
zlib is a general-purpose lossless data-compression library,
implementing an API for the DEFLATE algorithm, the latter of
which is being used by, for example, gzip and the ZIP archive
format.

%package -n mingw32-libz
Summary:        Zlib compression library
Group:          System/Libraries
Obsoletes:      %{name} < %{version}-%{release}
Provides:       %{name} = %{version}-%{release}

%description -n mingw32-libz
zlib is a general-purpose lossless data-compression library,
implementing an API for the DEFLATE algorithm, the latter of
which is being used by, for example, gzip and the ZIP archive
format.

Compatibility package.

%package devel
Summary:        Zlib compression library (development files)
Group:          Development/Libraries/C and C++
Requires:       mingw32-libz = %{version}

%description devel
zlib is a general-purpose lossless data-compression library,
implementing an API for the DEFLATE algorithm, the latter of
which is being used by, for example, gzip and the ZIP archive
format.

This subpackage holds the development headers for the library.

%package -n mingw32-libminizip1
Summary:        Zip archive library
Group:          System/Libraries
Obsoletes:      mingw32-minizip < %{version}-%{release}
Provides:       mingw32-minizip = %{version}-%{release}

%description -n  mingw32-libminizip1
Minizip is a library for manipulation with files from .zip archives.

%package -n mingw32-minizip-devel
Summary:        Development files for the minizip library
Group:          Development/Libraries/C and C++
Requires:       mingw32-libminizip1 = %{version}

%description -n mingw32-minizip-devel
This package contains the libraries and header files needed for
developing applications which use minizip.

%_mingw32_debug_package

%prep
%autosetup -p1 -n zlib-%{version}

%build
P=$(pwd)
%_mingw32_cmake . -DINSTALL_PKGCONFIG_DIR=%{_mingw32_libdir}/pkgconfig
%_mingw32_cmake_build CFLAGS=-shared LDFLAGS=-no-undefined

cd $P/contrib/minizip
autoreconf -fi
echo "lt_cv_deplibs_check_method='pass_all'" >>%{_mingw32_cache}
%{_mingw32_configure}

cp ../../zconf.h.included zconf.h
ln -s build/libz.dll.a ../..
%{_mingw32_make} CFLAGS=-shared LDFLAGS=-no-undefined

%install
%_mingw32_cmake_install
%make_install -C contrib/minizip
# for compatibility with older packages
ln -sf libz.dll %{buildroot}/%{_mingw32_bindir}/zlib1.dll

%files -n mingw32-zlib1
%{_mingw32_bindir}/zlib1.dll

%files -n mingw32-libz
%{_mingw32_bindir}/libz.dll

%files devel
%{_mingw32_includedir}/zconf.h
%{_mingw32_includedir}/zlib.h
%{_mingw32_libdir}/libz.dll.a
%{_mingw32_libdir}/libz.a
%{_mingw32_libdir}/pkgconfig/zlib.pc
%{_mingw32_libdir}/pkgconfig/zlib-static.pc
%{_mingw32_datadir}/man

%files -n mingw32-libminizip1
%{_mingw32_bindir}/libminizip-1.dll

%files -n mingw32-minizip-devel
%{_mingw32_includedir}/minizip/
%{_mingw32_libdir}/libminizip.dll.a
%{_mingw32_libdir}/pkgconfig/minizip.pc

%changelog
* Tue Mar 28 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Use absolute path to change into minizp source dir to be independent
  from the current path used by mingw32-cross-cmake provided
  macros
- Drop obsolete build dependencies (boo#1201119)
* Tue Mar 28 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Use mingw32-cross-cmake package (boo#1209611)
* Fri Mar 17 2023 Ralf Habacker <ralf.habacker@freenet.de>
- Fix not finding zconf.h and libz.dll.a with autotools submodule build
- Use cmake provided macros
- Fix warning that package obsoletes itself
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.13:
  * Fix configure issue that discarded provided CC definition
  * Correct incorrect inputs provided to the CRC functions
  * Repair prototypes and exporting of new CRC functions
  * Fix inflateBack to detect invalid input with distances too far
  * Have infback() deliver all of the available output up to any error
  * Fix a bug when getting a gzip header extra field with inflate
  * Fix bug in block type selection when Z_FIXED used
  * Tighten deflateBound bounds
  * Remove deleted assembler code references
  * Various portability and appearance improvements
* Mon Apr  4 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to 1.2.12
  * Fix a deflate bug when using the Z_FIXED strategy that can
    result in out-of-bound accesses. (bsc#1197459)
  * Fix a deflate bug when the window is full in deflate_stored().
  * Speed up CRC-32 computations by a factor of 1.5 to 3.
  * Use the hardware CRC-32 instruction on ARMv8 processors.
  * Speed up crc32_combine() with powers of x tables.
  * Add crc32_combine_gen() and crc32_combine_op() for fast combines.
* Mon Jan 10 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Add runtime package as dependency to development package to fix
  running cross compiled application (boo#1194430)
* Thu Sep 30 2021 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile for Factory resubmission:
  * trim rpmlintrc/post-build-checks ignores to minimum
  * apply descriptions from main zlib.spec
  * replace old specfile constructs like %%defattr
* Sun May  5 2019 ralf.habacker@freenet.de
- migrate to cmake to support static library
  (Adapting the custom configure script required too much effort)
- use mingw filename pattern for shared library (libz.dll) to
  prevent conflicts with preinstalled z libraries on native Windows
- let zlib1.dll still be existant for compatibility
